@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 
-from . import fabd, system, git, version, virtualenv, nginx, django, pip, \
+from . import fabd, system, git, release, virtualenv, nginx, django, pip, \
     postgres, mysql, supervisor, users, ssh, tar, gunicorn, uwsgi, rabbitmq, \
     apache, redis
 from .base import setup_fabdeploy
